@@ -32,6 +32,7 @@ class quantum_lab():
             uploadType: str, 
             shot: int, 
             filePath: str, 
+            timeout = 120
         ):
         url = "http://sdt-api.qcc.svc.cluster.local"
         url_path = f"{url}/qcc/notebook/job"
@@ -56,8 +57,8 @@ class quantum_lab():
         
         data = response.json()
         
-        print("{:<15} {:<5}".format("ID", "Status"))
-        print("{:<15} {:<5}".format(data["jobId"], data["status"]))
+        print("{:<6} {:<15}".format("ID", "Created Status"))
+        print("{:<6} {:<15}".format(data["jobId"], 'Success' if data["status"] else 'Fail'))
 
         jobID = data["id"]
 
@@ -67,12 +68,12 @@ class quantum_lab():
             response = requests.get(f"http://sdt-api.qcc.svc.cluster.local/qcc/notebook/job/{jobID}", headers=headers) 
             data = response.json()
             p_status = data["jobStatus"]
-            print(f"Time: {time_num} / Status: {p_status}", end='\r')
+            print(f"Time: {time_num} / Job Status: {p_status}        ", end='\r')
             if p_status == "Success" or p_status == "Failed":
                 break
             time_num += 1
 
-            if time_num > 60:
+            if time_num > timeout:
                 print("TimeOut...")
                 break
 
@@ -107,8 +108,9 @@ class quantum_lab():
         
         data = response.json()
         
-        print("{:<15} {:<5}".format("ID", "Status"))
-        print("{:<15} {:<5}".format(data["jobId"], data["status"]))
+
+        print("{:<6} {:<15}".format("ID", "Created Status"))
+        print("{:<6} {:<15}".format(data["id"], 'Success' if data["status"] else 'Fail'))
         
         return data["jobId"]
 
